@@ -30,21 +30,22 @@ class GameController : public QObject
     Q_OBJECT
 
 public:
-    GameController(const QString &path, FileDescriptor fd, libevdev *evdev);
+    explicit GameController(const QString &path, FileDescriptor &&fd, libevdev *evdev);
     ~GameController();
 
     const QString &path() const;
     int fd() const;
     libevdev *evdev() const;
 
-    void countUsage(int n);
+    void increaseUsageCount();
+    void decreaseUsageCount();
     int usageCount();
 
 private:
-    void addInputDevice(EmulatedInputDevice *inputDevice);
-    void removeInputDevice(EmulatedInputDevice *inputDevice);
     void handleEvdevEvent();
     void logEvent(input_event *ev);
+    void enableInputEmulation();
+
     bool isTestEnvironment = qEnvironmentVariableIsSet("KWIN_GAMECONTROLLER_TEST");
 
     const QString m_path;
